@@ -8,6 +8,23 @@ class CSVReader(FileHandler):
     def __init__(self, file_path, dialect=None, truncate=False, **fmtparams):
         super().__init__(file_path=file_path, dialect=dialect, truncate=truncate, **fmtparams)
 
+    def max_rows(self, file_path=None):
+        row_num = -1
+
+        if file_path:
+            self.file_path = file_path
+
+        if self.file_path:
+            with Lock(filename=self.file_path, mode='r') as read_obj:
+                csv_reader = reader(read_obj)
+
+                for line in csv_reader:
+                    row_num += 1
+        else:
+            row_num = 0
+
+        return row_num
+
     def parse(self):
         if self.streams:
             for handler, buffer in self.streams:
