@@ -29,22 +29,29 @@ class OpenPYXLReader(FileHandler):
         else:
             return self.__parse()
 
-    def max_rows(self):
-        from openpyxl import load_workbook
-
-        xls_file = load_workbook(self.file_path)
+    def max_rows(self, file_path=None, sheet_names=None):
         sheets = dict()
 
-        try:
-            for tab in xls_file.sheetnames:
-                if not self.sheet_names or tab.lower() in self.sheet_names:
-                    sheets[tab] = xls_ws.max_row
+        if file_path:
+            self.file_path = file_path
 
-        finally:
-            xls_file.close()
+        if sheet_names:
+            self.sheet_names = sheet_names
 
-        if sheets:
-            return sheets
+        if self.file_path:
+            from openpyxl import load_workbook
+
+            xls_file = load_workbook(self.file_path)
+            
+            try:
+                for tab in xls_file.sheetnames:
+                    if not self.sheet_names or tab.lower() in self.sheet_names:
+                        sheets[tab] = xls_ws.max_row
+
+            finally:
+                xls_file.close()
+
+        return sheets
 
     def __parse(self, handler=None, buffer=None):
         from openpyxl import load_workbook
